@@ -1,7 +1,6 @@
-package Pcore::API::Namecheap v0.3.4;
+package Pcore::API::Namecheap v0.4.0;
 
-use Pcore -dist, -class;
-use Pcore::API::Response;
+use Pcore -dist, -class, -status;
 
 has api_user => ( is => 'ro', isa => Str, required => 1 );
 has api_key  => ( is => 'ro', isa => Str, required => 1 );
@@ -99,11 +98,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
 
     # nothing to search
     if ( !$query_index ) {
-        my $api_res = Pcore::API::Response->new( { status => 200 } );
-
-        $api_res->{result} = $domains_index;
-
-        $cb->($api_res);
+        $cb->( status 200, $domains_index );
 
         $self->{_threads}--;
 
@@ -126,15 +121,17 @@ sub search ( $self, $domains = undef, $cb = undef ) {
             my $api_res;
 
             if ( $res->status != 200 ) {
-                $api_res = Pcore::API::Response->new( { status => $res->status, reason => $res->reason } );
+                $api_res = status [ $res->status, $res->reason ];
             }
             else {
                 my $hash = P->data->from_xml( $res->body );
 
                 if ( $hash->{ApiResponse}->{Errors}->[0]->{Error} ) {
                     for my $error ( $hash->{ApiResponse}->{Errors}->[0]->{Error}->@* ) {
-                        if ( $error->{Number}->[0]->{content} != 2_030_280 ) {    # provider for tld was not found
-                            $api_res = Pcore::API::Response->new( { status => $error->{Number}->[0]->{content}, reason => $error->{content} } );
+
+                        # provider for tld was not found
+                        if ( $error->{Number}->[0]->{content} != 2_030_280 ) {
+                            $api_res = status [ $error->{Number}->[0]->{content}, $error->{content} ];
 
                             last;
                         }
@@ -155,9 +152,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
                         }
                     }
 
-                    $api_res = Pcore::API::Response->new( { status => 200 } );
-
-                    $api_res->{result} = $domains_index;
+                    $api_res = status 200, $domains_index;
                 }
             }
 
@@ -181,9 +176,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 36                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (24)                    |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 115                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 35                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (24)                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
